@@ -8,10 +8,10 @@
 """
 import decimal
 import logging
-from datetime import datetime, date
-
 from base64 import b64encode, b64decode
 from collections import defaultdict
+from datetime import datetime, date
+
 from sqlalchemy.orm.collections import InstrumentedList
 
 logger = logging.getLogger(__name__)
@@ -60,6 +60,8 @@ V_FALSE = "0"
 
 ISO8601_ORA = "YYYY-MM-DD HH24:MI:SS.FF6"
 ISO8601 = "%Y-%m-%d %H:%M:%S.%f%z"
+ISO8601_JS_REGEXP = r"^\d{4}-\d{2}-\d{2}T\d{2}:\d{2}:\d{2}\.\d{3}[Z]{1}"
+ISO8601_JS_FORMAT = "%Y-%m-%dT%H:%M:%S.%fZ"
 ISO8601_REGEXP = r"^\d{4}-\d{2}-\d{2} \d{2}:\d{2}:\d{2}\.\d{6}[+-]\d{4}$"
 ISO8601_NOTZ = "%Y-%m-%d %H:%M:%S.%f"
 
@@ -206,8 +208,14 @@ def toStr(obj) -> str:
 
 def fromStr(val: str, typeName: str):
     if typeName == T_DATETIME:
+        # TODO: Check with ISO8601_JS_REGEXP
+        if len(val) == len("2017-06-06T09:40:37.097Z"):
+            return datetime.strptime(val, ISO8601_JS_FORMAT)
+
         if len(val) <= len("2017-06-06 09:40:37.097068"):
+            logger.warning("Parsing date time with no timezone: %s", val)
             return datetime.strptime(val, ISO8601_NOTZ)
+
         return datetime.strptime(val, ISO8601)
 
     if typeName == T_BOOL:
