@@ -69,6 +69,9 @@ class VortexPayloadHttpClientProtocol(VortexPayloadProtocol):
                 name=self._serverVortexName, uuid=self._serverVortexUuid
             )
 
+    def _createResponseSenderCallable(self):
+        raise NotImplementedError()
+
 
 class VortexClientHttp(VortexABC):
     """VortexServer Client
@@ -120,6 +123,10 @@ class VortexClientHttp(VortexABC):
             VortexInfo(name=self._serverVortexName, uuid=self._serverVortexUuid)
         ]
 
+    @property
+    def requiresBase64Encoding(self) -> bool:
+        raise NotImplementedError()
+
     @property
     def name(self):
         return self._vortexName
