@@ -9,7 +9,7 @@ from typing import Union
 
 import pytz
 from OpenSSL import SSL
-from rx.subjects import Subject
+from reactivex.subject import Subject
 from twisted.internet import reactor
 from twisted.internet import ssl
 from twisted.internet._sslverify import trustRootFromCertificates
@@ -19,13 +19,13 @@ from twisted.internet.defer import inlineCallbacks
 from twisted.internet.defer import succeed
 from twisted.internet.task import deferLater
 from twisted.python.failure import Failure
-
 from txhttputil.util.PemUtil import parsePemBundleForClient
 from txhttputil.util.PemUtil import parsePemBundleForServer
 from txhttputil.util.PemUtil import parsePemBundleForTrustedPeers
 from txhttputil.util.SslUtil import buildCertificateOptionsForTwisted
 from txhttputil.util.SslUtil import parseTrustRootFromBundle
 from txwebsocket.txws import WebSocketFactory
+
 from vortex.DeferUtil import yesMainThread
 from vortex.PayloadEnvelope import PayloadEnvelope
 from vortex.PayloadEnvelope import VortexMsgList
@@ -64,12 +64,11 @@ _ConnectionDateSuccess = namedtuple(
 
 
 class _VortexConnectionRateLimit:
-    _ROLLING_WINDOW_SECONDS = 10.0
-    _NEW_CONNECTIONS_IN_WINDOW = 5
-
     def __init__(self):
         self._connections: list[_ConnectionDateSuccess] = []
         self._peerConnectionLimitPerIp = None
+        self._newConnectionsPerWindow = 5
+        self._rollingNewConnectionWindowSeconds = 10.0
 
     def _hasHitPeerConnectionLimit(
         self, connectionCountForPeer: int, fromIp: str
@@ -103,7 +102,7 @@ class _VortexConnectionRateLimit:
         self._connections = list(
             filter(
                 lambda item: (now - item.dateTime).total_seconds()
-                < self._ROLLING_WINDOW_SECONDS,
+                < self._rollingNewConnectionWindowSeconds,
                 self._connections,
             )
         )
@@ -112,7 +111,7 @@ class _VortexConnectionRateLimit:
             list(filter(lambda item: item.success, self._connections))
         )
 
-        if connectedInWindow < self._NEW_CONNECTIONS_IN_WINDOW:
+        if connectedInWindow < self._newConnectionsPerWindow:
             self._connections.append(_ConnectionDateSuccess(now, True, fromIp))
             return True
 
@@ -133,9 +132,15 @@ class _VortexConnectionRateLimit:
 
         return False
 
+    def setNewConnectionsPerWindow(self, limit):
+        self._newConnectionsPerWindow = limit
+
     def setPeerConnectionLimitPerIp(self, limit):
         self._peerConnectionLimitPerIp = limit
 
+    def setRollingNewConnectionWindowSeconds(self, seconds):
+        self._rollingNewConnectionWindowSeconds = seconds
+
 
 VortexUuidList = List[str]
 
@@ -182,7 +187,6 @@ class _VortexFactoryVortexInfo:
         self.rebuildStructs()
 
     def rebuildStructs(self):
-
         vortexServers = []
         for vortexes in self.__vortexServersByName.values():
             vortexServers.extend(vortexes)
@@ -268,7 +272,42 @@ class _VortexFactoryVortexInfo:
             )
         ]
 
-    def getRemoteVortexInfoByIp(self, ip: str, vortexName=None) -> str:
+    def getRemoteVortexIpByUuid(self, vortexUuid: str, vortexName=None) -> str:
+        from vortex.VortexConnectionABC import VortexConnectionABC
+
+        targetConns: list[VortexConnectionABC] = []
+        for server in self.vortexSevers:
+            for conn in server.connections.values():
+                if (
+                    not conn.closed
+                    and not conn.timedOut
+                    and conn.remoteVortexUuid == vortexUuid
+                    and (
+                        conn.remoteVortexName == vortexName
+                        or vortexName is None
+                    )
+                ):
+                    targetConns.append(conn)
+
+        if len(targetConns) > 1:
+            logger.warning(
+                "Multiple vortexes found for uuid=%s, name=%s,"
+                " choosing latest connection",
+                vortexUuid,
+                vortexName,
+            )
+            targetConns.sort(key=lambda c: c.connectDateTime)
+            # As of Python3.6, dict are ordered, so the newest is the last.
+            return targetConns[-1].ip
+
+        if not targetConns:
+            raise NoVortexException(
+                f"Can not find vortex with UUID {vortexUuid}"
+            )
+
+        return targetConns[0].ip
+
+    def getRemoteVortexUuidByIp(self, ip: str, vortexName=None) -> str:
         # Ignore the port if any
         ip = ip.split(":")[0]
 
@@ -387,6 +426,14 @@ class VortexFactory:
     def setPeerConnectionLimitPerIp(cls, limit: int):
         cls.__connectionRateLimit.setPeerConnectionLimitPerIp(limit)
 
+    @classmethod
+    def setNewConnectionsPerWindow(cls, limit):
+        cls.__connectionRateLimit.setNewConnectionsPerWindow(limit)
+
+    @classmethod
+    def setRollingNewConnectionWindowSeconds(cls, seconds):
+        cls.__connectionRateLimit.setRollingNewConnectionWindowSeconds(seconds)
+
     @classmethod
     def createServer(cls, name: str, rootResource) -> None:
         """Create Server
@@ -724,12 +771,23 @@ class VortexFactory:
     def getRemoteVortexName(cls) -> list[str]:
         return cls.__vortexInfoState.getRemoteVortexNames
 
+    @classmethod
+    def getRemoteVortexIpByUuid(cls, vortexUuid: str, vortexName=None) -> str:
+        return cls.__vortexInfoState.getRemoteVortexIpByUuid(
+            vortexUuid=vortexUuid, vortexName=vortexName
+        )
+
     @classmethod
     def getRemoteVortexInfoByIp(cls, ip: str, vortexName=None) -> str:
-        return cls.__vortexInfoState.getRemoteVortexInfoByIp(
+        return cls.__vortexInfoState.getRemoteVortexUuidByIp(
             ip=ip, vortexName=vortexName
         )
 
+    @classmethod
+    def getRemoteVortexUuidByIp(cls, ip: str, vortexName=None) -> str:
+        # alias to getRemoteVortexInfoByIp
+        return cls.getRemoteVortexInfoByIp(ip=ip, vortexName=vortexName)
+
     @classmethod
     @inlineCallbacks
     def sendVortexMsg(
