@@ -156,7 +156,11 @@ class TupleActionProcessor:
         tupleAction = payload.tuples[0]
 
         yield self._processTupleAction(
-            payloadEnvelope.filt, sendResponse, tupleAction, **kwargs
+            payloadEnvelope.filt,
+            sendResponse,
+            tupleAction,
+            vortexUuid=vortexUuid,
+            **kwargs,
         )
 
     def _processTupleAction(
