@@ -2,7 +2,8 @@ import logging
 from copy import copy
 from typing import List
 
-from rx.subjects import Subject
+from reactivex.subject import Subject
+from reactivex import operators as ops
 from twisted.internet.defer import Deferred, inlineCallbacks
 
 from vortex.DeferUtil import vortexLogFailure
@@ -62,9 +63,9 @@ class TupleDataObserverClient(TupleDataObservableCache):
         # .subscribe(online= > self.vortexOnlineChanged())
         #
         # self.onDestroyEvent.subscribe(() = > isOnlineSub.unsubscribe())
-        VortexFactory.subscribeToVortexStatusChange(destVortexName).filter(
+        VortexFactory.subscribeToVortexStatusChange(destVortexName).pipe(ops.filter(
             lambda online: online is True
-        ).subscribe(self._vortexOnlineChanged)
+        )).subscribe(self._vortexOnlineChanged)
 
         TupleDataObservableCache.start(self)
 
